Welcome to the ``reticle`` Documentation!
=========================================

.. code-block:: bash

    ❯ pip install reticle

Features
--------

- Submit Batch jobs

.. toctree::
   :maxdepth: 2

   reticle
   CONTRIBUTING